Learn R Programming

CRABS (version 1.2.0)

joint.congruent.models: Create a set of congruent models

Description

Create a set of congruent models

Usage

joint.congruent.models(model, mus, lambdas, keep_ref = TRUE)

Value

An object of class "CRABSset"

Arguments

model

The reference model. An object of class "CRABS"

mus

A list of extinction-rate functions

lambdas

A list of speciation-rate functions

keep_ref

Whether or not to keep the reference model in the congruent set

Examples

Run this code

# This function should not have to be used externally.
# It is called in the CRABS function `sample.congruence.class` when `rate.type=="joint"`.

Run the code above in your browser using DataLab