primates_ebd_treepar: TreePar Primates birth-death model
Description
The results of a birth-death model in the R-package TreePar, fitted on the primates tree. The estimated model has two epochs, that are maximum-likelihood estimates. The time unit is millions of years before the present.
Usage
data(primates_ebd_treepar)
Arguments
Format
An object of class tbl_df (inherits from tbl, data.frame) with 100 rows and 3 columns.