- posterior
a list of CRABS model objects
- num.samples
The number of samples to be drawn
- rate.type
either "extinction", "speciation", "both" or "joint"
- mu0.equal
whether to propose alternative mu starting at mu0 equal to the posterior sample. default to FALSE
- rate0
rate0 allows the user to fix the extinction rate at the present to a single value. defaults to NULL, for drawing it randomly
- ...
Arguments passed on to sample.basic.models
times
the time knots
model
"MRF" for pure MRF model, otherwise MRF has a trend of type "exponential","linear", or "episodic<n>"
direction
"increase" or "decrease" (measured in past to present)
noisy
If FALSE, no MRF noise is added to the trajectory
MRF.type
"HSMRF" or "GMRF", type for stochastic noise.
monotonic
Whether the curve should be forced to always move in one direction.
fc.mean
Determines the average amount of change when drawing from the model.
rate0.median
When not specified, rate at present is drawn from a lognormal distribution with this median.
rate0.logsd
When not specified, rate at present is drawn from a lognormal distribution with this sd
mrf.sd.scale
scale the sd of the mrf process up or down. defaults to 1.0
min.rate
The minimum rate (rescaling fone after after drawing rates).
max.rate
The maximum rate (rescaling fone after after drawing rates).