powered by
Create a set of congruent models
joint.congruent.models(model, mus, lambdas, keep_ref = TRUE)
An object of class "CRABSset"
The reference model. An object of class "CRABS"
A list of extinction-rate functions
A list of speciation-rate functions
Whether or not to keep the reference model in the congruent set
# This function should not have to be used externally. # It is called in the CRABS function `sample.congruence.class` when `rate.type=="joint"`.
Run the code above in your browser using DataLab